<?php

namespace App\Http\Livewire\Dashboard;

use Livewire\Component;
use Illuminate\Support\Facades\DB;

class DashboardMod extends Component
{
    public $userId;
    private $monthLabel = array();
    private $hiresNumber = array();

    public function countFranchises()
    {
        return DB::table('rh_employees')
            ->join('rh_agences', 'rh_agences.AGENCE_ID', '=', 'rh_employees.EMPLOYEE_FKAGENCEID')
            ->where('rh_agences.AGENCE_NOM', '!=', 'ICC Développement')
            ->count();
    }

    public function countICCDev()
    {
        return DB::table('rh_employees')
            ->join('rh_agences', 'rh_agences.AGENCE_ID', '=', 'rh_employees.EMPLOYEE_FKAGENCEID')
            ->where('rh_agences.AGENCE_NOM', '=', 'ICC Développement')
            ->count();
    }

    public function lastHires()
    {
        return DB::table('rh_employees')
            ->join('rh_agences', 'rh_agences.AGENCE_ID', '=', 'rh_employees.EMPLOYEE_FKAGENCEID')
            ->orderBy('rh_employees.EMPLOYEE_DATEARRIVEE', 'desc')
            ->limit(3)
            ->get();
    }

    public function countAgencesFranchisees()
    {
        return DB::table('rh_agences')
            ->where('rh_agences.AGENCE_TYPE', '=', 'Franchise')
            ->count();
    }

    public function countAgencesFiliales()
    {
        return DB::table('rh_agences')
            ->where('rh_agences.AGENCE_TYPE', '=', 'Filiale')
            ->count();
    }

    public function countOriasEnCours()
    {
        return DB::table('rh_orias')
            ->where('ORIAS_ETAT', '=', 'EN COURS')
            ->count();
    }

    public function countOriasAFaire()
    {
        return DB::table('rh_orias')
            ->where('ORIAS_ETAT', '=', NULL)
            ->count();
    }

    public function countIeamEnCours()
    {
        return DB::table('rh_ieam')
            ->where('IEAM_ETAT', '=', 'EN COURS')
            ->count();
    }

    public function countIeamAFaire()
    {
        return DB::table('rh_ieam')
            ->where('IEAM_ETAT', '=', NULL)
            ->count();
    }

    public function countAfibEnCours()
    {
        return DB::table('rh_afib')
            ->where('AFIB_ETAT', '=', 'EN COURS')
            ->count();
    }

    public function countAfibAFaire()
    {
        return DB::table('rh_afib')
            ->where('AFIB_ETAT', '=', NULL)
            ->count();
    }

    public function countDevices()
    {
        return DB::table('rh_devices')
            ->count();
    }

    public function countDevicesExpiration()
    {
        $date = now();
        $date =  strtotime("-6 month", strtotime($date));
        $date = date('Y/m/d h:i:s', $date);

        return DB::table('rh_devices')
            ->where('DEVICE_ENROLLEDDATETIME', "<", $date)
            ->count();
    }

    public function countLastArrival()
    {
        $countLastArrival = DB::select("SELECT COUNT(*) NB_ARRIVANT , UPPER(DATE_FORMAT(EMPLOYEE_DATEARRIVEE, '%M', 'FR_FR')) MOIS
            FROM RH_EMPLOYEES
            WHERE EMPLOYEE_DATEARRIVEE BETWEEN DATE_ADD(CURRENT_DATE(),INTERVAL -8 MONTH) AND CURRENT_DATE()
            GROUP BY MONTHNAME(EMPLOYEE_DATEARRIVEE)
            ORDER BY EMPLOYEE_DATEARRIVEE ASC
        ");

        foreach ($countLastArrival as $arrival) {
            array_push($this->monthLabel, $arrival->MOIS);
            array_push($this->hiresNumber, $arrival->NB_ARRIVANT);
        }

        return ([$countLastArrival, $this->monthLabel, $this->hiresNumber]);
    }

    public $tableLayout;
    public $tableTitleIcon;
    public $tableTitle;

    public function render()
    {

        return view($this->tableLayout, [
            'tableLayout' => $this->tableLayout,
            'tableTitleIcon' => $this->tableTitleIcon,
            'tableTitle' => $this->tableTitle,
            'countFranchises' => $this->countFranchises(),
            'countICCDev' => $this->countICCDev(),
            'countAgencesFranchisees' => $this->countAgencesFranchisees(),
            'countAgencesFiliales' => $this->countAgencesFiliales(),
            'countOriasEnCours' => $this->countOriasEnCours(),
            'countOriasAFaire' => $this->countOriasAFaire(),
            'countIeamEnCours' => $this->countIeamEnCours(),
            'countIeamAFaire' => $this->countIeamAFaire(),
            'countAfibEnCours' => $this->countAfibEnCours(),
            'countAfibAFaire' => $this->countAfibAFaire(),
            'countDevices' => $this->countDevices(),
            'countDevicesExpiration' => $this->countDevicesExpiration(),
            'lastHires' => $this->lastHires(),
            'countLastArrival' => $this->countLastArrival(),
            'monthLabel' => $this->monthLabel,
            'hiresNumber' => $this->hiresNumber,
        ]);
    }
}
